@@ -35,6 +35,14 @@
 G_BEGIN_DECLS
 
 
+#define COGL_SYSDEF_POLLIN 1
+#define COGL_SYSDEF_POLLPRI 2
+#define COGL_SYSDEF_POLLOUT 4
+#define COGL_SYSDEF_POLLERR 8
+#define COGL_SYSDEF_POLLHUP 16
+#define COGL_SYSDEF_POLLNVAL 32
+
+#define COGL_HAS_GLIB_SUPPORT 1
 #define COGL_HAS_GL 1
 #define CLUTTER_COGL_HAS_GL 1
 #define COGL_HAS_GLX_SUPPORT 1
