@@ -12,16 +12,6 @@ G_BEGIN_DECLS
 GType cogl_bitmap_error_get_type (void) G_GNUC_CONST;
 #define COGL_TYPE_BITMAP_ERROR (cogl_bitmap_error_get_type())
 
-/* enumerations from "./cogl-buffer.h" */
-GType cogl_buffer_update_hint_get_type (void) G_GNUC_CONST;
-#define COGL_TYPE_BUFFER_UPDATE_HINT (cogl_buffer_update_hint_get_type())
-
-GType cogl_buffer_access_get_type (void) G_GNUC_CONST;
-#define COGL_TYPE_BUFFER_ACCESS (cogl_buffer_access_get_type())
-
-GType cogl_buffer_map_hint_get_type (void) G_GNUC_CONST;
-#define COGL_TYPE_BUFFER_MAP_HINT (cogl_buffer_map_hint_get_type())
-
 /* enumerations from "./cogl-material-compat.h" */
 GType cogl_material_filter_get_type (void) G_GNUC_CONST;
 #define COGL_TYPE_MATERIAL_FILTER (cogl_material_filter_get_type())
@@ -47,6 +37,9 @@ GType cogl_shader_type_get_type (void) G_GNUC_CONST;
 GType cogl_texture_error_get_type (void) G_GNUC_CONST;
 #define COGL_TYPE_TEXTURE_ERROR (cogl_texture_error_get_type())
 
+GType cogl_texture_type_get_type (void) G_GNUC_CONST;
+#define COGL_TYPE_TEXTURE_TYPE (cogl_texture_type_get_type())
+
 /* enumerations from "./cogl-types.h" */
 GType cogl_pixel_format_get_type (void) G_GNUC_CONST;
 #define COGL_TYPE_PIXEL_FORMAT (cogl_pixel_format_get_type())
@@ -90,7 +83,9 @@ GType cogl_winsys_feature_get_type (void) G_GNUC_CONST;
 GType cogl_color_mask_get_type (void) G_GNUC_CONST;
 #define COGL_TYPE_COLOR_MASK (cogl_color_mask_get_type())
 
-/* enumerations from "./cogl.h" */
+GType cogl_winding_get_type (void) G_GNUC_CONST;
+#define COGL_TYPE_WINDING (cogl_winding_get_type())
+
 GType cogl_buffer_bit_get_type (void) G_GNUC_CONST;
 #define COGL_TYPE_BUFFER_BIT (cogl_buffer_bit_get_type())
 
